==> haskell-finite-typelits-0.2.0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-finite-typelits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 finite-typelits
version:              0.2.0.1
visibility:           public
id:                   finite-typelits-0.2.0.1-KuuD1zQq5QSLSY39bFS6BZ
key:                  finite-typelits-0.2.0.1-KuuD1zQq5QSLSY39bFS6BZ
license:              BSD-3-Clause
maintainer:           mniip@mniip.com
author:               mniip
homepage:             https://github.com/mniip/finite-typelits
synopsis:
    A type inhabited by finitely many values, indexed by type-level naturals

description:
    A type inhabited by finitely many values, indexed by type-level naturals.

category:             Data
abi:                  208af95d26aff981b0e1c34c4fafaff0
exposed:              True
exposed-modules:
    Data.Finite Data.Finite.Integral Data.Finite.Internal
    Data.Finite.Internal.Integral

import-dirs:          /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-finite-typelits
hs-libraries:         HSfinite-typelits-0.2.0.1-KuuD1zQq5QSLSY39bFS6BZ
depends:
    base-4.17.2.1 deepseq-1.4.8.0 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-finite-typelits/html/finite-typelits.haddock

haddock-html:         /usr/share/doc/haskell-finite-typelits/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-finite-typelits-0.2.0.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-finite-typelits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 finite-typelits
version:              0.2.0.1
visibility:           public
id:                   finite-typelits-0.2.0.1-IOq18qBjsuPImDFBl1pnxM
key:                  finite-typelits-0.2.0.1-IOq18qBjsuPImDFBl1pnxM
license:              BSD-3-Clause
maintainer:           mniip@mniip.com
author:               mniip
homepage:             https://github.com/mniip/finite-typelits
synopsis:
    A type inhabited by finitely many values, indexed by type-level naturals

description:
    A type inhabited by finitely many values, indexed by type-level naturals.

category:             Data
abi:                  f1e8a4b7416594fb5666b4536c66ee1a
exposed:              True
exposed-modules:
    Data.Finite Data.Finite.Integral Data.Finite.Internal
    Data.Finite.Internal.Integral

import-dirs:          /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-finite-typelits
hs-libraries:         HSfinite-typelits-0.2.0.1-IOq18qBjsuPImDFBl1pnxM
depends:
    base-4.17.2.1 deepseq-1.4.8.0 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-finite-typelits/html/finite-typelits.haddock

haddock-html:         /usr/share/doc/haskell-finite-typelits/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
